# coding: utf-8

# flake8: noqa
"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from internal_integration_handler_connector.models.add_new_stream_recording_to_module import AddNewStreamRecordingToModule
from internal_integration_handler_connector.models.add_tags_to_portal_member_request import AddTagsToPortalMemberRequest
from internal_integration_handler_connector.models.add_user_to_group_chat import AddUserToGroupChat
from internal_integration_handler_connector.models.create_order_request import CreateOrderRequest
from internal_integration_handler_connector.models.http_validation_error import HTTPValidationError
from internal_integration_handler_connector.models.portal_member import PortalMember
from internal_integration_handler_connector.models.remove_tags_from_portal_member_request import RemoveTagsFromPortalMemberRequest
from internal_integration_handler_connector.models.remove_user_from_group_chat import RemoveUserFromGroupChat
from internal_integration_handler_connector.models.response_wrapper import ResponseWrapper
from internal_integration_handler_connector.models.response_wrapper_bool import ResponseWrapperBool
from internal_integration_handler_connector.models.response_wrapper_int import ResponseWrapperInt
from internal_integration_handler_connector.models.result import Result
from internal_integration_handler_connector.models.send_message_in_group_chat import SendMessageInGroupChat
from internal_integration_handler_connector.models.send_personal_message_to_user import SendPersonalMessageToUser
from internal_integration_handler_connector.models.validation_error import ValidationError
from internal_integration_handler_connector.models.validation_error_loc_inner import ValidationErrorLocInner
